@@ -35,6 +35,19 @@ class Session:
         self.http_session = requests.Session()
         self.http_session.headers.update(options["headers"])
 
+    @staticmethod
+    def initialize_endpoint_helper(*, context=None, **kwargs):
+        context = fetch_context(context)
+
+        alfa_env = fetch_alfa_env(kwargs, context=context)
+        alfa_id = fetch_setting("alfa_id", kwargs, context=context)
+        region = fetch_setting("platform_region", kwargs, context=context)
+
+        alfa_config = {"alfa_env": alfa_env, "alfa_id": alfa_id, "region": region}
+        return EndpointHelper(**alfa_config)
+
+    #
+
     def request(self, method, service, path, *, parse=True, **kwargs):
         url = self.endpoint.resolve(service, path)
         kwargs = filter_none_arguments(kwargs)
